@@ -7,7 +7,9 @@ from __future__ import print_function, division, absolute_import
 import numpy as np
 import os, sys
 import ellc
+import transitleastsquares as tls
 from transitleastsquares import catalog_info
+from transitleastsquares import transit_mask
 import astropy.constants as ac
 import astropy.units as u
 import lightkurve as lk
@@ -17,7 +19,7 @@ import pandas as pd
 np.random.seed(42)
 
 #::: load data and set the units correctly
-TIC_ID = 85400193    # TIC_ID of our candidate
+TIC_ID = 142748283    # TIC_ID of our candidate
 lcf= lk.search_lightcurvefile('TIC '+str(TIC_ID), mission="tess").download_all()
 ab, mass, massmin, massmax, radius, radiusmin, radiusmax = catalog_info(TIC_ID=TIC_ID)
 
@@ -45,12 +47,26 @@ rstar_max = radius+radiusmax
 #print('radius_max =', format(rstar_max,'0.5f'))
 
 
-lc=lcf.PDCSAP_FLUX.stitch().remove_nans() # remove of the nans
-lc_new=lk.LightCurve(time=lc.time, flux=lc.flux,flux_err=lc.flux_err)
-clean=lc_new.remove_outliers(sigma_lower=float('inf'), sigma_upper=3) #remove outliers over 3sigma
-flux0=clean.flux
-time=clean.time
+lc = lcf.PDCSAP_FLUX.stitch().remove_nans() # remove of the nans
+lc_new = lk.LightCurve(time=lc.time, flux=lc.flux,flux_err=lc.flux_err)
+clean = lc_new.remove_outliers(sigma_lower=float('inf'), sigma_upper=3) #remove outliers over 3sigma
+flux0 = clean.flux
+time = clean.time
 flux_err = clean.flux_err
+model = tls.transitleastsquares(time, flux0)
+results0 = model.power(M_star=mass, M_star_max=mstar_max, M_star_min=mstar_min, R_star=radius,
+                      R_star_min=rstar_min, R_star_max=rstar_max,
+                      period_min=0.4, period_max=7)
+mask0 = transit_mask(time, results0.period, results0.duration, results0.T0)
+time0 = time[~mask0]
+flux1 = flux0[~mask0]
+flux_err1 = flux_err[~mask0]
+model = tls.transitleastsquares(time0, flux1)
+results1 = model.power(M_star=mass, M_star_max=mstar_max, M_star_min=mstar_min, R_star=radius,
+                      R_star_min=rstar_min, R_star_max=rstar_max,
+                      period_min=0.4, period_max=7)
+mask1 = transit_mask(time, results1.period, results1.duration, results1.T0)
+
 #period_maximum=(max(time)-min(time))/2.
 #time, flux0 = np.genfromtxt('TESS_phot.csv', delimiter=',', unpack=True)
 #rstar = 0.211257 * 41.46650444642 #in Rearth
@@ -150,18 +166,22 @@ def logprint(*text):
 
     
 #::: iterate through grid of periods and rplanet
-dir = "/home/pozuelos/martin/curves"
+dir = "/home/pozuelos/martin/ir/toi2096/curves"
 if not os.path.isdir(dir):
     os.mkdir(dir)
-max_period = 10
+max_period = 40
 min_period = 0.5
-for period in np.arange(min_period, max_period, 0.5):
-    for t0 in np.arange(time[60], time[60] + period - 0.1, period / 5):
-        for rplanet in np.arange(4, 0.65, -0.1):
+for period in np.arange(min_period, max_period, 1.0):
+    for t0 in np.arange(time[60], time[60] + period - 0.1, period / 4):
+        for rplanet in np.arange(4, 0.65, -0.2):
             rplanet = np.around(rplanet, decimals=2)*u.R_earth
             print('\n')
             print('P = '+str(period)+' days, Rp = '+str(rplanet) + ", T0 = " + str(t0))
             time_model, flux_model, flux_err_model = make_model(t0, period, rplanet)
+            if len(time_model) > 0:
+                time_model = time_model[~mask0 & ~mask1]
+                flux_model = flux_model[~mask0 & ~mask1]
+                flux_err_model = flux_err_model[~mask0 & ~mask1]
             file_name = os.path.join(dir + '/P' + str(period) + '_R' + str(rplanet.value) + '_' + str(t0) + '.csv')
             lc_df = pd.DataFrame(columns=['#time', 'flux', 'flux_err'])
             lc_df['#time'] = time_model
